{
  # Snowfall Lib provides a customized `lib` instance with access to your flake's library
  # as well as the libraries available from your flake's inputs.
  lib,
  # An instance of `pkgs` with your overlays and packages applied is also available.
  pkgs,
  # You also have access to your flake's inputs.
  inputs,

  # Additional metadata is provided by Snowfall Lib.
  namespace, # The namespace used for your flake, defaulting to "internal" if not set.
  home,
  target, # The Snowfall Lib target for this home (eg. `x86_64-home`).
  format, # A normalized name for the home target (eg. `home`).
  virtual, # A boolean to determine whether this home is a virtual target using nixos-generators.
  host, # The host name for this home.

  # All other arguments come from the home home.
  config,
  ...
}@arguments:
{
  home.username = "julian";
  home.homeDirectory = "/home/julian";

  modules = {
    non-nixos.is-nixos = true;

    shell = {
      fish.enable = true;
    };
    yazi.enable = true;
    topgrade.enable = true;
    neovim.enable = true;
    wezterm.enable = true;
    nix-helper.enable = true;

    desktop.enable = true;
    fonts.enable = true;
  };

  services.syncthing.tray.enable = true;
  services.syncthing.tray.command = "syncthingtray --wait"; # Wait for tray to become available

  home.packages = with pkgs; [
    music-reader
    sheet-organizer

    xournalpp
    musescore

    onboard
  ];

  # Autostart link
  home.file = {
    ".config/autostart/sheet-organizer.desktop".source =
      "${pkgs.sheet-organizer}/share/applications/sheet-organizer.desktop";
    ".config/sheet-organizer/config.toml".text = ''
      working_directory = "/home/julian/Klavier"
    '';
  };

  # Let Home Manager install and manage itself.
  programs.home-manager.enable = true;

  # ======================== DO NOT CHANGE THIS ========================
  home.stateVersion = "23.11";
  # ======================== DO NOT CHANGE THIS ========================
}
