{
  # Snowfall Lib provides a customized `lib` instance with access to your flake's library
  # as well as the libraries available from your flake's inputs.
  lib,
  # An instance of `pkgs` with your overlays and packages applied is also available.
  pkgs,
  # You also have access to your flake's inputs.
  inputs,

  # Additional metadata is provided by Snowfall Lib.
  system, # The system architecture for this host (eg. `x86_64-linux`).
  target, # The Snowfall Lib target for this system (eg. `x86_64-iso`).
  format, # A normalized name for the system target (eg. `iso`).
  virtual, # A boolean to determine whether this system is a virtual target using nixos-generators.
  systems, # An attribute map of your defined hosts.

  # All other arguments come from the module system.
  config,
  host,
  ...
}:

let
  cfg = config.modules.suites.cli;
in
{
  options.modules.suites.cli = {
    enable = lib.mkOption { default = false; };
  };

  config = lib.mkIf cfg.enable {
    home.packages = with pkgs; [
      bat
      du-dust # Like du tree but better
      fd # better find
      fdupes # find and delete duplicate files
      ffmpeg
      findutils # locate
      fzf # Fuzzy finder
      ghostscript # needed for imagemagick with pdfs
      imagemagick
      git
      gnupg
      htop
      jq # Command line JSON processor
      killall
      languagetool # Grammar checker
      lazygit # Git client
      links2 # Tui web-browser
      lnav # log analyzing tool
      mc # Tui file browser
      # nix-index
      nmap
      p7zip # unzip 7zip archives
      parted
      pciutils # lspci
      poppler_utils # Pdf utils including pdfimages
      libqalculate # Nice tui calculator (qalc)
      ripgrep # better grep
      rnr # renaming tool
      sage # Maths notebooks
      tealdeer # tldr
      topgrade # System update
      tree
      unetbootin # TODO
      unixtools.procps # TODO
      unzip
      usbutils # lsusb
      wget
      wireguard-tools # wg-quick
      xorg.xkill
      zip

      ## My scripts
      frajul.edit-config
      frajul.lntocp
    ];
  };
}
