{
  # Snowfall Lib provides a customized `lib` instance with access to your flake's library
  # as well as the libraries available from your flake's inputs.
  lib,
  # An instance of `pkgs` with your overlays and packages applied is also available.
  pkgs,
  # You also have access to your flake's inputs.
  inputs,

  # Additional metadata is provided by Snowfall Lib.
  system, # The system architecture for this host (eg. `x86_64-linux`).
  target, # The Snowfall Lib target for this system (eg. `x86_64-iso`).
  format, # A normalized name for the system target (eg. `iso`).
  virtual, # A boolean to determine whether this system is a virtual target using nixos-generators.
  systems, # An attribute map of your defined hosts.

  # All other arguments come from the module system.
  config,
  host,
  ...
}:

let
  cfg = config.modules.suites.development;
in
{
  options.modules.suites.development = {
    enable = lib.mkOption { default = false; };
  };

  config = lib.mkIf cfg.enable {
    home.packages = with pkgs; [
      watchexec # Run command when any file in current dir changes
      android-tools # adb
      # shellcheck # Check bash scripts for common errors
      sqlite
      scrcpy # Mirror android screen to pc
      cargo
      clippy
      cntr # nix debugger
      conda
      micromamba # a better, faster conda
      devcontainer # development container
      devenv # devbox alternative
      dbeaver-bin
      devbox # dev environments using nix
      distrobox # run commands inside docker containers
      gcc
      gradle
      hexedit
      unstable.zed-editor
      jdk
      julia-bin
      (texlive.combine {
        # for rendering latex in inkscape
        inherit (texlive)
          scheme-medium
          standalone
          amsmath
          preview
          ;
      })
      matlab # Using nix-matlab overlay defined in flake
      maven
      nodejs
      pkg-config # Often needed to build something
      pwndbg # improved gdb (debugger)
      python3
      rust-analyzer
      rustc
      rustfmt
      # (pkgs.inkscape-with-extensions.override {
      #   inkscapeExtensions = [ pkgs.inkscape-extensions.textext ];
      # })
      # inkscape-with-extensions
      # inkscape-extensions.textext
      inkscape
      gcolor3 # Color picker
      gimp
      drawio
      audacity

      deploy-rs
      sops
      pandoc # markdown preview
      docker-compose

      ## My scripts
      frajul.deploy-to-pianopi

      (pkgs.writeShellScriptBin "matlab-rsp" ''
        matlab -desktop -sd "/home/julian/git/uwa-channel-model" -softwareopengl
      '')

      (pkgs.writeShellScriptBin "matlab-paper" ''
        matlab -desktop -sd "/home/julian/dev/phdthesis/Phase B/mainSimulation" -softwareopengl
      '')
      (pkgs.writeShellScriptBin "matlab-robotik" ''
        matlab -desktop -sd "/home/julian/nas-sync/Studium/Vorlesungen-Master/ss24/Robotik2" -softwareopengl
      '')
      (pkgs.writeShellScriptBin "matlab-gram" ''
        export GTK_PATH=/usr/lib/gtk-3.0
        nix shell nixpkgs#gcc11 --command matlab -desktop -sd "/home/julian/dev/matlab-gram" -softwareopengl
      '')
      (pkgs.writeShellScriptBin "expenses-tracker" ''
        java -jar /home/julian/dev/expensestracker/app/build/libs/app.jar
      '')
    ];
  };
}
